@@ -352,6 +352,14 @@ def validate_rai_insights(
     for ind_data in rai_insights._string_ind_data:
         assert len(ind_data) == expected_length
 
+    if rai_insights.model is None:
+        assert rai_insights.predict_output is None
+        assert rai_insights.predict_proba_output is None
+    else:
+        assert rai_insights.predict_output is not None
+        if task_type == ModelTask.CLASSIFICATION:
+            assert rai_insights.predict_proba_output is not None
+
     if task_type == ModelTask.CLASSIFICATION:
         classes = train_data[target_column].unique()
         classes.sort()
